![PyPI - Downloads](https://img.shields.io/pypi/dm/easyT)
![PyPI](https://img.shields.io/pypi/v/easyT)
![PyPI - Wheel](https://img.shields.io/pypi/wheel/easyT)
![PyPI - License](https://img.shields.io/pypi/l/easyT)

# easyT

- easyT,
  - easyTo trade,
    - easyTo use!
  
# WARNING!

Now that I have your attention I would like you to reflect about the fact that **$1.00 Dollar** might be **not** 
that **much** to you, but **you, an incredible person**, combined to other's **amazing Sponsors**, can **finance** this 
project, and it will **allow me** to constantly **improve and maintain** it, **and, I am not asking that much**.

Here is my [Patreon](https://www.patreon.com/joaopeuko) link.

  - _Yeah, I would like to do that, but I do not have that kind of money._ 

That is Ok, and, there are many ways you can help me, here is a list:

  - **Star** this project on GitHub.
  - **Share** this project.
  - **Open an account with Binance referral link**:
    - When you open an account on Binance you help me when you trade!
    - Some of your tax paid returns for you and part goes for me.
    - Below you can see the percentage cash back for me and for you, and you trade:
        
    |For me | For you | Link|
    |:--------| :----:  |  ---:|
    | 10%| 10%     | https://accounts.binance.com/en/register?ref=IBNF8RAW | 
    | 15%| 5%      | https://accounts.binance.com/en/register?ref=D11OJ6NP | 
    | 20%| 0%      | https://accounts.binance.com/en/register?ref=SAUNZ26X | 
      - You can find more information about the **Binance** referral link [here](https://www.binance.com/en/support/faq/88659d2ea54c40cf82a22400207ffe30)
      
  - And, there are **Ads** in all the documentations, that hopefully, will help me finance this project.

# Summary

- [Requirements](#requirements)
- [Libraries Documentation](#libraries-documentation)

# Requirements

The first thing tou will need is **Python** installed in your computer.
Right now, it is required the version 3.8.

- _Yeah, ok, but I do not know how to install Python on my computer, or I do not want to install it._
  - _Can I still use it?_

In parts, you can use Notebooks that allows you to use Python direct from the web, test the code and, understand how
things works before try it in your computer.
Two famous Notebooks are **Google Colaboratory** and **Jupyter Notebook**.

I will provide examples!

Remember that the use of an IDE can make your live easier, I use **PYCHARM**!

On your favorite IDE, you can use some project that you already have or create a new one, and then you install it:

```python
pip install easyT
```

That is it! The first steps are completed!


# Libraries Documentation

All the Libraries Documentation and useful links are linked below:

- easyT - [Documentation](https://joaopeuko.github.io/easyT/) - [GitHub](https://github.com/Joaopeuko/easyT) - [Pypi](https://pypi.org/project/easyT/) 
  - binanceSpotEasyT - [Documentation](https://joaopeuko.github.io/binanceSpotEasyT/) - [GitHub](https://github.com/Joaopeuko/binanceSpotEasyT) - [Pypi](https://pypi.org/project/binanceSpotEasyT/) 
  - metatrader5EasyT - [Documentation](https://joaopeuko.github.io/metatrader5EasyT/) - [GitHub](https://github.com/Joaopeuko/metatrader5EasyT) - [Pypi](https://pypi.org/project/metatrader5EasyT/)
- Mql5-Python-Integration - [GitHub](https://joaopeuko.github.io/Mql5-Python-Integration/)

The documentation for this specific project is this one [easyT](https://joaopeuko.github.io/easyT/).

See my page ([Joao Paulo Euko](https://joaopeuko.github.io/)) to see all my projects or for more information.

